@@ -1,6 +1,6 @@
 package Net::Kubernetes::Role::ResourceCreator;
 # ABSTRACT: Role to allow creation of resources from either objects or files.
-$Net::Kubernetes::Role::ResourceCreator::VERSION = '0.11';
+$Net::Kubernetes::Role::ResourceCreator::VERSION = '0.12';
 use Moose::Role;
 use MooseX::Aliases;
 require YAML::XS;
@@ -51,7 +51,7 @@ sub create {
 	my $content = $self->json->encode($object);
 	$content =~ s/(["'])(true|false)\1/$2/g;
 	# /EndHack
-	my $req = $self->create_request(POST=>$self->path.'/'.lc($object->{kind}).'s', undef, $content);
+    my $req = $self->create_request(POST=>$self->path.'/'.lc($object->{kind}).'s', undef, $content);
 	my $res = $self->ua->request($req);
 	if ($res->is_success) {
 		return $self->create_resource_object($self->json->decode($res->content));
@@ -70,6 +70,11 @@ sub create {
 
 
 sub build_secret {
+	my($self, $name, $data) = @_;
+	return $self->create($self->_assemble_secret($name, $data));
+}
+
+sub _assemble_secret {
 	my($self, $name, $data) = @_;
 	my($secret) = {
 		kind => 'Secret',
@@ -106,7 +111,7 @@ sub build_secret {
 		}
 		
 	}
-	return $self->create($secret);
+	return $secret;
 }
 
 
@@ -124,7 +129,7 @@ Net::Kubernetes::Role::ResourceCreator - Role to allow creation of resources fro
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 METHODS
 
@@ -142,12 +147,23 @@ Create from file is really just a short cut around something like:
 =head2 build_secret($name, $data)
 
 Builds a Kubernetes secret object with $name. $data is a hash reference whose keys will be keys int the created secret.
-The value for each key should be either a filename (which will be slurped into the secret), or a hashref with the
-keys "type" and "value.  Valid types are "JSON", "YAML" or "String" (anything other that "JSON" or "YAML") will be
-assumed to be of type "String". If either "JSON" or "YAML" the "value" will be serialized out before placing in the
-secret.
 
-  my($new_secret) = $kube->build_secret('donttell', { ssh_public_key => '/home/dave/.ssh/id_rsa.pub', super_sceret_daata => {type => 'JSON', value=>{username=>'Dave', password=>'Imnottelling'}}});
+The value for each key should be either a filename (which will be slurped into
+the secret), or a hashref with the keys "type" and "value".
+
+Valid types are "JSON", "YAML" or "String" (anything other that "JSON" or
+"YAML") will be assumed to be of type "String". If either "JSON" or "YAML" the
+"value" will be serialized out before placing in the secret.
+
+Note that the keys must be valid DNS subdomains (underscore is not allowed) and must be lowercase.
+
+  my ($new_secret) = $kube->build_secret('donttell', {
+    ssh-public-key => '/home/dave/.ssh/id_rsa.pub',
+    super-secret-data => {
+        type  => 'JSON',
+        value => { username => 'Dave', password => 'Imnottelling' },
+    }
+  });
 
 =head1 AUTHOR
 
