@@ -1,6 +1,6 @@
 package Net::Kubernetes::Role::ResourceLister;
 # ABSTRACT: Role to give access to list_* methods.
-$Net::Kubernetes::Role::ResourceLister::VERSION = '0.11';
+$Net::Kubernetes::Role::ResourceLister::VERSION = '0.12';
 use Moose::Role;
 use MooseX::Aliases;
 require Net::Kubernetes::Resource::Service;
@@ -106,6 +106,35 @@ sub list_services {
 }
 
 
+sub list_events {
+	my $self = shift;
+	my(%options);
+	if (ref($_[0])) {
+		%options = %{ $_[0] };
+	}else{
+		%options = @_;
+	}
+
+	my $uri = URI->new($self->path.'/events');
+	my(%form) = ();
+	$form{labelSelector}=$self->_build_selector_from_hash($options{labels}) if (exists $options{labels});
+	$form{fieldSelector}=$self->_build_selector_from_hash($options{fields}) if (exists $options{fields});
+	$uri->query_form(%form);
+
+	my $res = $self->ua->request($self->create_request(GET => $uri));
+	if ($res->is_success) {
+		my $event_list = $self->json->decode($res->content);
+		my(@events)=();
+		foreach my $service (@{ $event_list->{items}}){
+			$service->{apiVersion} = $event_list->{apiVersion};
+			push @events, $self->create_resource_object($service, 'Event');
+		}
+		return wantarray ? @events : \@events;
+	}else{
+		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$res->message);
+	}
+}
+
 
 sub list_secrets {
 	my $self = shift;
@@ -159,7 +188,7 @@ Net::Kubernetes::Role::ResourceLister - Role to give access to list_* methods.
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 METHODS
 
@@ -179,6 +208,10 @@ returns a list of L<Net::Kubernetes::Resource::ReplicationController>s
 
 returns a list of L<Net::Kubernetes::Resource::Service>s
 
+=head2 list_events([label=>{label=>value}], [fields=>{field=>value}])
+
+returns a list of L<Net::Kubernetes::Resource::Service>s
+
 =head2 list_secrets([label=>{label=>value}], [fields=>{field=>value}])
 
 returns a list of L<Net::Kubernetes::Resource::Secret>s
